pub struct DataEngineConfig {
pub time_bars_build_with_no_updates: bool,
pub time_bars_timestamp_on_close: bool,
pub time_bars_skip_first_non_full_bar: bool,
pub time_bars_interval_type: BarIntervalType,
pub time_bars_build_delay: u64,
pub time_bars_origins: HashMap<BarAggregation, Duration>,
pub validate_data_sequence: bool,
pub buffer_deltas: bool,
pub emit_quotes_from_book: bool,
pub emit_quotes_from_book_depths: bool,
pub external_clients: Option<Vec<ClientId>>,
pub debug: bool,
}Expand description
Configuration for DataEngine instances.
Fields
time_bars_build_with_no_updates: boolIf time bar aggregators will build and emit bars with no new market updates.
time_bars_timestamp_on_close: boolIf time bar aggregators will timestamp ts_event on bar close.
If False, then will timestamp on bar open.
time_bars_skip_first_non_full_bar: boolIf time bar aggregators will skip emitting a bar if the aggregation starts mid-interval.
time_bars_interval_type: BarIntervalTypeDetermines the type of interval used for time aggregation.
LeftOpen: start time is excluded and end time is included (default).RightOpen: start time is included and end time is excluded.
time_bars_build_delay: u64The time delay (microseconds) before building and emitting a bar.
time_bars_origins: HashMap<BarAggregation, Duration>A dictionary mapping time bar aggregations to their origin time offsets.
validate_data_sequence: boolIf data objects timestamp sequencing will be validated and handled.
buffer_deltas: boolIf order book deltas should be buffered until the F_LAST flag is set for a delta.
emit_quotes_from_book: boolIf quotes should be emitted on order book updates.
emit_quotes_from_book_depths: boolIf quotes should be emitted on order book depth updates.
external_clients: Option<Vec<ClientId>>The client IDs declared for external stream processing. The data engine will not attempt to send data commands to these client IDs.
debug: boolIf debug mode is active (will provide extra debug logging).
Implementations
Sourceimpl DataEngineConfig
impl DataEngineConfig
Sourcepub fn builder() -> DataEngineConfigBuilder
pub fn builder() -> DataEngineConfigBuilder
Create an instance of DataEngineConfig using the builder syntax